
Authentication at a central location.
-------

**Description:**

Authentication should always be performed at a central location in the application in 
order to prevent missing authentication on certain levels in the application.


**Solution:**

Use a central location for authentication.

	